diff --git a/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php b/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
index 3da5abc..c5b23a6 100644
--- a/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
+++ b/core/lib/Drupal/Core/Entity/EntityStorageControllerInterface.php
@@ -21,16 +21,6 @@
 interface EntityStorageControllerInterface {
 
   /**
-   * Load the most recent version of an entity's field data.
-   */
-  const FIELD_LOAD_CURRENT = 'FIELD_LOAD_CURRENT';
-
-  /**
-   * Load the version of an entity's field data specified in the entity.
-   */
-  const FIELD_LOAD_REVISION = 'FIELD_LOAD_REVISION';
-
-  /**
    * Resets the internal, static entity cache.
    *
    * @param $ids
diff --git a/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php b/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
index 222145f..b9d26f6 100644
--- a/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
+++ b/core/lib/Drupal/Core/Entity/FieldableDatabaseStorageController.php
@@ -774,16 +774,14 @@ public function getQueryServiceName() {
   /**
    * {@inheritdoc}
    */
-  protected function doLoadFieldItems($entities, $age) {
-    $load_current = $age == static::FIELD_LOAD_CURRENT;
-
+  protected function doLoadFieldItems($entities, $load_revisions) {
     // Collect entities ids, bundles and languages.
     $bundles = array();
     $ids = array();
     $default_langcodes = array();
     foreach ($entities as $key => $entity) {
       $bundles[$entity->bundle()] = TRUE;
-      $ids[] = $load_current ? $key : $entity->getRevisionId();
+      $ids[] = $load_revisions ? $entity->getRevisionId() : $key;
       $default_langcodes[$key] = $entity->getUntranslated()->language()->id;
     }
 
@@ -798,14 +796,14 @@ protected function doLoadFieldItems($entities, $age) {
     // Load field data.
     $langcodes = array_keys(language_list(Language::STATE_ALL));
     foreach ($fields as $field_name => $field) {
-      $table = $load_current ? static::_fieldTableName($field) : static::_fieldRevisionTableName($field);
+      $table = $load_revisions ? static::_fieldRevisionTableName($field) : static::_fieldTableName($field);
 
       // Ensure that only values having valid languages are retrieved. Since we
       // are loading values for multiple entities, we cannot limit the query to
       // the available translations.
       $results = $this->database->select($table, 't')
         ->fields('t')
-        ->condition($load_current ? 'entity_id' : 'revision_id', $ids, 'IN')
+        ->condition($load_revisions ? 'revision_id' : 'entity_id', $ids, 'IN')
         ->condition('deleted', 0)
         ->condition('langcode', $langcodes, 'IN')
         ->orderBy('delta')
diff --git a/core/lib/Drupal/Core/Entity/Query/QueryBase.php b/core/lib/Drupal/Core/Entity/Query/QueryBase.php
index e98755a..6578644 100644
--- a/core/lib/Drupal/Core/Entity/Query/QueryBase.php
+++ b/core/lib/Drupal/Core/Entity/Query/QueryBase.php
@@ -110,12 +110,9 @@
   /**
    * Flag indicating whether to query the current revision or all revisions.
    *
-   * Can be either EntityStorageControllerInterface::FIELD_LOAD_CURRENT or
-   * EntityStorageControllerInterface::FIELD_LOAD_REVISION.
-   *
-   * @var string
+   * @var bool
    */
-  protected $age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT;
+  protected $loadRevisions = FALSE;
 
   /**
    * The query pager data.
@@ -259,10 +256,10 @@ public function accessCheck($access_check = TRUE) {
   }
 
   /**
-   * Implements \Drupal\Core\Entity\Query\QueryInterface::age().
+   * {@inheritdoc}
    */
-  public function age($age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
-    $this->age = $age;
+  public function loadRevisions() {
+    $this->loadRevisions = TRUE;
     return $this;
   }
 
diff --git a/core/lib/Drupal/Core/Entity/Query/QueryInterface.php b/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
index 4a9420b..09bd4cd 100644
--- a/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
+++ b/core/lib/Drupal/Core/Entity/Query/QueryInterface.php
@@ -152,22 +152,16 @@ public function tableSort(&$headers);
   public function accessCheck($access_check = TRUE);
 
   /**
-   * Queries the current or every revision.
+   * Queries every revision.
    *
    * Note that this only affects field conditions. Property conditions always
    * apply to the current revision.
    * @TODO: Once revision tables have been cleaned up, revisit this.
    *
-   * @param $age
-   *   - EntityStorageControllerInterface::FIELD_LOAD_CURRENT (default): Query
-   *     the most recent revisions only,
-   *   - EntityStorageControllerInterface::FIELD_LOAD_REVISION: Query all
-   *     revisions.
-   *
-   * @return \Drupal\Core\Entity\Query\QueryInterface
-   *   The called object.
+   * @return $this
    */
-  public function age($age = EntityStorageControllerInterface::FIELD_LOAD_CURRENT);
+  public function loadRevisions();
+
 
   /**
    * Execute the query.
diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/Query.php b/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
index 407cef5..a7f28df 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/Query.php
@@ -146,7 +146,7 @@ protected function prepare() {
     }
     // This now contains first the table containing entity properties and
     // last the entity base table. They might be the same.
-    $this->sqlQuery->addMetaData('age', $this->age);
+    $this->sqlQuery->addMetaData('load_revisions', $this->loadRevisions);
     $this->sqlQuery->addMetaData('simple_query', $simple_query);
     return $this;
   }
diff --git a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
index 7308431..3815fa9 100644
--- a/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
+++ b/core/lib/Drupal/Core/Entity/Query/Sql/Tables.php
@@ -59,7 +59,7 @@ public function addField($field, $type, $langcode) {
     $entity_type_id = $this->sqlQuery->getMetaData('entity_type');
     $entity_manager = \Drupal::entityManager();
     $field_info = FieldInfo::fieldInfo();
-    $age = $this->sqlQuery->getMetaData('age');
+    $load_revisions = $this->sqlQuery->getMetaData('load_revisions');
     // This variable ensures grouping works correctly. For example:
     // ->condition('tags', 2, '>')
     // ->condition('tags', 20, '<')
@@ -83,7 +83,7 @@ public function addField($field, $type, $langcode) {
     for ($key = 0; $key <= $count; $key ++) {
       // If there is revision support and only the current revision is being
       // queried then use the revision id. Otherwise, the entity id will do.
-      if (($revision_key = $entity_type->getKey('revision')) && $age == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+      if (($revision_key = $entity_type->getKey('revision')) && !$load_revisions) {
         // This contains the relevant SQL field to be used when joining entity
         // tables.
         $entity_id_field = $revision_key;
@@ -252,11 +252,10 @@ protected function ensureEntityTable($index_prefix, $property, $type, $langcode,
   protected function ensureFieldTable($index_prefix, &$field, $type, $langcode, $base_table, $entity_id_field, $field_id_field) {
     $field_name = $field->getName();
     if (!isset($this->fieldTables[$index_prefix . $field_name])) {
-      $table = $this->sqlQuery->getMetaData('age') == EntityStorageControllerInterface::FIELD_LOAD_CURRENT ? FieldableDatabaseStorageController::_fieldTableName($field) : FieldableDatabaseStorageController::_fieldRevisionTableName($field);
+      $table = $this->sqlQuery->getMetaData('load_revisions') ? FieldableDatabaseStorageController::_fieldRevisionTableName($field) : FieldableDatabaseStorageController::_fieldTableName($field) ;
       if ($field->getCardinality() != 1) {
         $this->sqlQuery->addMetaData('simple_query', FALSE);
       }
-      $entity_type = $this->sqlQuery->getMetaData('entity_type');
       $this->fieldTables[$index_prefix . $field_name] = $this->addJoin($type, $table, "%alias.$field_id_field = $base_table.$entity_id_field", $langcode);
     }
     return $this->fieldTables[$index_prefix . $field_name];
diff --git a/core/modules/field/field.views.inc b/core/modules/field/field.views.inc
index 885134b..5637491 100644
--- a/core/modules/field/field.views.inc
+++ b/core/modules/field/field.views.inc
@@ -139,20 +139,20 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
 
   // Description of the field tables.
   $field_tables = array(
-    EntityStorageControllerInterface::FIELD_LOAD_CURRENT => array(
+    FALSE => array(
       'table' => FieldableDatabaseStorageController::_fieldTableName($field),
       'alias' => "{$entity_type_id}__{$field_name}",
     ),
   );
   if ($supports_revisions) {
-    $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION] = array(
+    $field_tables[TRUE] = array(
       'table' => FieldableDatabaseStorageController::_fieldRevisionTableName($field),
       'alias' => "{$entity_type_id}_revision__{$field_name}",
     );
   }
 
   // Build the relationships between the field table and the entity tables.
-  $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_CURRENT]['alias'];
+  $table_alias = $field_tables[FALSE]['alias'];
   $data[$table_alias]['table']['join'][$entity_table] = array(
     'left_field' => $entity_type->getKey('id'),
     'field' => 'entity_id',
@@ -161,7 +161,7 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
     ),
   );
   if ($supports_revisions) {
-    $table_alias = $field_tables[EntityStorageControllerInterface::FIELD_LOAD_REVISION]['alias'];
+    $table_alias = $field_tables[FALSE]['alias'];
     $data[$table_alias]['table']['join'][$entity_revision_table] = array(
       'left_field' => $entity_type->getKey('revision'),
       'field' => 'revision_id',
@@ -185,18 +185,18 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
   list($label, $all_labels) = field_views_field_label($entity_type_id, $field_name);
 
   // Expose data for the field as a whole.
-  foreach ($field_tables as $type => $table_info) {
+  foreach ($field_tables as $load_revisions => $table_info) {
     $table = $table_info['table'];
     $table_alias = $table_info['alias'];
 
-    if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
-      $group = $group_name;
-      $field_alias = $field_name;
-    }
-    else {
+    if ($load_revisions) {
       $group = t('@group (historical data)', array('@group' => $group_name));
       $field_alias = $field_name . '-revision_id';
     }
+    else {
+      $group = $group_name;
+      $field_alias = $field_name;
+    }
 
     $data[$table_alias][$field_alias] = array(
       'group' => $group,
@@ -210,7 +210,7 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
     $aliases = array();
     $also_known = array();
     foreach ($all_labels as $label_name => $true) {
-      if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
+      if (!$load_revisions) {
         if ($label != $label_name) {
           $aliases[] = array(
             'base' => $entity_table,
@@ -249,7 +249,7 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
       'entity_tables' => $entity_tables,
       // Default the element type to div, let the UI change it if necessary.
       'element type' => 'div',
-      'is revision' => $type == EntityStorageControllerInterface::FIELD_LOAD_REVISION,
+      'is revision' => $load_revisions,
     );
   }
 
@@ -291,15 +291,15 @@ function field_views_field_default_views_data(FieldConfigInterface $field) {
     }
 
     // Expose data for the property.
-    foreach ($field_tables as $type => $table_info) {
+    foreach ($field_tables as $load_revisions => $table_info) {
       $table = $table_info['table'];
       $table_alias = $table_info['alias'];
 
-      if ($type == EntityStorageControllerInterface::FIELD_LOAD_CURRENT) {
-        $group = $group_name;
+      if ($load_revisions) {
+        $group = t('@group (historical data)', array('@group' => $group_name));
       }
       else {
-        $group = t('@group (historical data)', array('@group' => $group_name));
+        $group = $group_name;
       }
       $column_real_name = FieldableDatabaseStorageController::_fieldColumnName($field, $column);
 
diff --git a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
index 54657f2..ccc41d6 100644
--- a/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
+++ b/core/modules/field/lib/Drupal/field/Plugin/views/field/Field.php
@@ -228,7 +228,7 @@ public function query($use_groupby = FALSE) {
       $options += is_array($this->options['group_columns']) ? $this->options['group_columns'] : array();
 
       $fields = array();
-      $rkey = $this->definition['is revision'] ? EntityStorageControllerInterface::FIELD_LOAD_REVISION : EntityStorageControllerInterface::FIELD_LOAD_CURRENT;
+      $rkey = $this->definition['is revision'];
       // Go through the list and determine the actual column name from field api.
       foreach ($options as $column) {
         $name = $column;
diff --git a/core/modules/file/file.module b/core/modules/file/file.module
index ed7592f..efe0b98 100644
--- a/core/modules/file/file.module
+++ b/core/modules/file/file.module
@@ -619,7 +619,7 @@ function file_file_download($uri, $field_type = 'file') {
   }
 
   // Find out which (if any) fields of this type contain the file.
-  $references = file_get_file_references($file, NULL, EntityStorageControllerInterface::FIELD_LOAD_CURRENT, $field_type);
+  $references = file_get_file_references($file, NULL, TRUE, $field_type);
 
   // Stop processing if there are no references in order to avoid returning
   // headers for files controlled by other modules. Make an exception for
@@ -1838,32 +1838,30 @@ function file_icon_map(File $file) {
  *
  * @param \Drupal\file\File $file
  *   A file entity.
- * @param $field
+ * @param array $field
  *   (optional) A field array to be used for this check. If given, limits the
  *   reference check to the given field.
- * @param $age
- *   (optional) A constant that specifies which references to count. Use
- *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to retrieve all
- *   references within all revisions or
- *   EntityStorageControllerInterface::FIELD_LOAD_CURRENT to retrieve references
- *   only in the current revisions.
- * @param $field_type
+ * @param bool $load_current
+ *   (optional) A flag that specifies which references to count. Use
+ *   FALSE to retrieve all references within all revisions or TRUE to retrieve
+ *   references only in the current revisions.
+ * @param string $field_type
  *   (optional) The name of a field type. If given, limits the reference check
  *   to fields of the given type. If both $field and $field_type is given but
  *   $field is not the same type as $field_type, an empty array will be
  *   returned.
  *
- * @return
+ * @return array
  *   A multidimensional array. The keys are field_name, entity_type,
  *   entity_id and the value is an entity referencing this file.
  */
-function file_get_file_references(File $file, $field = NULL, $age = EntityStorageControllerInterface::FIELD_LOAD_REVISION, $field_type = 'file') {
+function file_get_file_references(File $file, $field = NULL, $load_current = FALSE, $field_type = 'file') {
   $references = &drupal_static(__FUNCTION__, array());
   $field_columns = &drupal_static(__FUNCTION__ . ':field_columns', array());
 
   // Fill the static cache, disregard $field and $field_type for now.
-  if (!isset($references[$file->id()][$age])) {
-    $references[$file->id()][$age] = array();
+  if (!isset($references[$file->id()][$load_current])) {
+    $references[$file->id()][$load_current] = array();
     $usage_list = \Drupal::service('file.usage')->listUsage($file);
     $file_usage_list = isset($usage_list['file']) ? $usage_list['file'] : array();
     foreach ($file_usage_list as $entity_type_id => $entity_ids) {
@@ -1871,7 +1869,7 @@ function file_get_file_references(File $file, $field = NULL, $age = EntityStorag
       // The usage table contains usage of every revision. If we are looking
       // for every revision or the entity does not support revisions then
       // every usage is already a match.
-      $match_entity_type = $age == EntityStorageControllerInterface::FIELD_LOAD_REVISION || !$entity_type->hasKey('revision');
+      $match_entity_type = !$load_current || !$entity_type->hasKey('revision');
       $entities = entity_load_multiple($entity_type_id, array_keys($entity_ids));
       foreach ($entities as $entity) {
         $bundle = $entity->bundle();
@@ -1908,13 +1906,13 @@ function file_get_file_references(File $file, $field = NULL, $age = EntityStorag
             }
           }
           if ($match) {
-            $references[$file->id()][$age][$field_name][$entity_type_id][$entity->id()] = $entity;
+            $references[$file->id()][$load_current][$field_name][$entity_type_id][$entity->id()] = $entity;
           }
         }
       }
     }
   }
-  $return = $references[$file->id()][$age];
+  $return = $references[$file->id()][$load_current];
   // Filter the static cache down to the requested entries. The usual static
   // cache is very small so this will be very fast.
   if ($field || $field_type) {
diff --git a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
index c01a2e2..019ed2f 100644
--- a/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
+++ b/core/modules/system/lib/Drupal/system/Tests/Entity/EntityQueryTest.php
@@ -249,7 +249,7 @@ function testEntityQuery() {
     $this->assertResult();
     $this->queryResults = $this->factory->get('entity_test_mulrev')
       ->condition("$greetings.value", 'merhaba')
-      ->age(EntityStorageControllerInterface::FIELD_LOAD_REVISION)
+      ->loadRevisions()
       ->sort('revision_id')
       ->execute();
     // Bit 2 needs to be set.
@@ -279,7 +279,7 @@ function testEntityQuery() {
     $this->assertIdentical($results, array_slice($assert, 4, 8, TRUE));
     $results = $this->factory->get('entity_test_mulrev')
       ->condition("$greetings.value", 'a', 'ENDS_WITH')
-      ->age(EntityStorageControllerInterface::FIELD_LOAD_REVISION)
+      ->loadRevisions()
       ->sort('id')
       ->execute();
     // Now we get everything.

diff --git a/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php b/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
index ec468b7..5e27fb7 100644
--- a/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
+++ b/core/lib/Drupal/Core/Entity/FieldableEntityStorageControllerBase.php
@@ -110,18 +110,17 @@ protected function loadFieldItems(array $entities) {
       return;
     }
 
-    $age = static::FIELD_LOAD_CURRENT;
+    $load_revisions = FALSE;
     foreach ($entities as $entity) {
       if (!$entity->isDefaultRevision()) {
-        $age = static::FIELD_LOAD_REVISION;
+        $load_revisions = TRUE;
         break;
       }
     }
 
     // Only the most current revision of non-deleted fields for cacheable entity
     // types can be cached.
-    $load_current = $age == static::FIELD_LOAD_CURRENT;
-    $use_cache = $load_current && $this->entityType->isFieldDataCacheable();
+    $use_cache = !$load_revisions && $this->entityType->isFieldDataCacheable();
 
     // Assume all entities will need to be queried. Entities found in the cache
     // will be removed from the list.
@@ -156,7 +155,7 @@ protected function loadFieldItems(array $entities) {
     // Fetch other entities from their storage location.
     if ($queried_entities) {
       // Let the storage controller actually load the values.
-      $this->doLoadFieldItems($queried_entities, $age);
+      $this->doLoadFieldItems($queried_entities, $load_revisions);
 
       // Build cache data.
       // @todo: Improve this logic to avoid instantiating field objects once
@@ -252,13 +251,11 @@ protected function deleteFieldItemsRevision(EntityInterface $entity) {
    *
    * @param array $entities
    *   An array of entities keyed by entity ID.
    * @param int $age
    *   EntityStorageControllerInterface::FIELD_LOAD_CURRENT to load the most
    *   recent revision for all fields, or
    *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to load the version
    *   indicated by each entity.
    */
-  abstract protected function doLoadFieldItems($entities, $age);
+  abstract protected function doLoadFieldItems($entities, $load_revisions);
 
   /**
    * Saves values of configurable fields for an entity.
@@ -252,13 +251,11 @@ protected function deleteFieldItemsRevision(EntityInterface $entity) {
    * @param array $entities
    *   An array of entities keyed by entity ID.
-   * @param int $age
-   *   EntityStorageControllerInterface::FIELD_LOAD_CURRENT to load the most
-   *   recent revision for all fields, or
-   *   EntityStorageControllerInterface::FIELD_LOAD_REVISION to load the version
-   *   indicated by each entity.
+   * @param bool $load_revisions
+   *   TRUE to load the version indicated by each entity, or FALSE to load the
+   *   most recent revision for all fields.
    */